@@ -21,7 +21,7 @@ use English                qw(-no_match_vars);
 use Carp                   qw(carp croak confess);
 use Cwd                    qw();
 
-our $VERSION     = '0.19';
+our $VERSION     = '0.20';
 our @EXPORT      = qw();
 our @EXPORT_OK   = qw(dist_pkgname dist_pkgver);
 our @EXPORT_TAGS = ( ':all' => \@EXPORT_OK );
@@ -137,6 +137,7 @@ problem.
 our ($Is_dependency, $PKGDEST, $PACKAGER, $DEBUG);
 
 $PACKAGER = 'Anonymous';
+$DEBUG    = $ENV{DIST_ARCH_DEBUG};
 
 sub _DEBUG
 {
@@ -259,6 +260,35 @@ sub prepare
     return $self->SUPER::prepare(@_);
 }
 
+#---HELPER FUNCTION---
+sub _find_built_pkg
+{
+    my ($self, $pkg_type, $destdir) = @_;
+    my $status = $self->status;
+
+    my $pkgfile = catfile( $destdir,
+                           join '-',
+                           ( $status->pkgname,
+                             $status->pkgver,
+                             $status->pkgrel,
+                             join '.',
+                             ( $pkg_type eq q{bin}
+                               ? ( $status->pkgarch, 'pkg' )
+                               : 'src' ),
+                             'tar',
+                            ));
+
+    _DEBUG "Searching for file starting with $pkgfile";
+
+    my ($found) =
+        ( grep { -f $_ }
+          map { "$pkgfile.$_" } qw/ xz gz / );
+
+    _DEBUG ( $found ? "Found $found" : "No package file found!" );
+
+    return $found;
+}
+
 #---INTERFACE METHOD---
 # Purpose  : Creates the pacman package using the 'makepkg' command.
 #----------------------
@@ -314,21 +344,11 @@ Package type must be 'bin' or 'src'};
     }
 
     # Prepare our file name paths for pkgfile and source tarball...
-    my $pkgfile = join '-', ( qq{${\$status->pkgname}},
-                              qq{${\$status->pkgver}},
-                              ( $pkg_type eq q{bin}
-                                ? ( q{1},
-                                    qq{${\$status->pkgarch}.pkg.tar.gz} )
-                                : q{1.src.tar.gz} )
-                             );
-
     my $srcfile_fqp = $status->pkgbase . '/' . $module->package;
-    my $pkgfile_fqp = $status->pkgbase . "/$pkgfile";
 
     $status->destdir( $opts{destdir} ) if $opts{destdir};
     my $destdir = $status->destdir;
     $destdir = Cwd::abs_path( $destdir );
-    my $destfile_fqp = catfile( $destdir, $pkgfile );
 
     # Prepare our 'makepkg' package building directory,
     # namely the PKGBUILD and source tarball files...
@@ -367,7 +387,7 @@ Package type must be 'bin' or 'src'};
 
     chdir $oldcwd or die "chdir: $OS_ERROR";
 
-    $status->dist( $destfile_fqp );
+    $status->dist( $self->_find_built_pkg( $pkg_type, $destdir ));
     return $status->created( 1 );
 }
 
@@ -633,7 +653,10 @@ sub get_pkgbuild
     my %pkgvars = $self->get_pkgvars;
 
     # Quote our package desc for bash.
-    $pkgvars{pkgdesc} =~ s/ ([\$\"\`\!]) / \\$1 /gxms;
+    $pkgvars{pkgdesc} =~ s/ ([\$\"\`]) / \\$1 /gxms;
+    
+    # !'s are much more annoying...
+    $pkgvars{pkgdesc} =~ s/ \! /"'!'"/xms;
 
     my $templ_vars = { packager  => $ENV{PACKAGER} || $PACKAGER,
                        version   => $VERSION,
@@ -809,6 +832,7 @@ sub _pod_pkgdesc
     a lesser module in the same package file.
     
     Assume the main .pm or .pod file is under lib/Module/Name/Here.pm
+
 =cut
 
     my $mainmod_path = $mod_obj->package_name;
